@@ -89,8 +89,6 @@ SEXP _nlmixr2est_filterNormalLikeAndDoses(SEXP, SEXP, SEXP);
 
 SEXP _nlmixr2est_rxode2hasLlik(void);
 
-typedef SEXP (*_rxode2random_rxRmvnSEXP_t)(SEXP nSSEXP, SEXP muSSEXP, SEXP sigmaSSEXP, SEXP lowerSSEXP, SEXP upperSSEXP, SEXP ncoresSSEXP, SEXP isCholSSEXP, SEXP keepNamesSSEXP, SEXP aSSEXP, SEXP tolSSEXP, SEXP nlTolSSEXP, SEXP nlMaxiterSSEXP);
-_rxode2random_rxRmvnSEXP_t rxRmvnSEXPnlmixrEst;
 SEXP _nlmixr2est_RcppExport_registerCCallable(void);
 
 SEXP _nlmixr2est_nlmSetup(SEXP);
@@ -115,25 +113,20 @@ SEXP _nlmixr2est_nlmSetScaleC(SEXP);
 SEXP _nlmixr2est_nlmPrintHeader(void);
 SEXP _nlmixr2est_nlmGetParHist(SEXP);
 
-SEXP _nlmixr2est_popedSolveIdN(SEXP, SEXP, SEXP, SEXP);
-SEXP _nlmixr2est_popedSolveIdN2(SEXP, SEXP, SEXP, SEXP);
-SEXP _nlmixr2est_popedSetup(SEXP, SEXP);
-SEXP _nlmixr2est_popedFree(void);
+SEXP _nlmixr2est_iniLotriPtr(SEXP ptr);
 
-SEXP _nlmixr2est_popedSolveIdME(SEXP, SEXP, SEXP, SEXP, SEXP,
-                                SEXP, SEXP);
-SEXP _nlmixr2est_popedSolveIdME2(SEXP, SEXP, SEXP, SEXP, SEXP,
-                                 SEXP, SEXP);
+SEXP _nlmixr2est_iniRxodePtrs(SEXP ptr);
 
+SEXP _nlmixr2est_iniN1qn1cPtrs(SEXP ptr);
+
+SEXP _nlmixr2est_iniLbfgsb3ptr(SEXP ptr);
 
 static const R_CallMethodDef CallEntries[] = {
+  {"_nlmixr2est_iniLbfgsb3ptr", (DL_FUNC) &_nlmixr2est_iniLbfgsb3ptr, 1},
+  {"_nlmixr2est_iniN1qn1cPtrs", (DL_FUNC) &_nlmixr2est_iniN1qn1cPtrs, 1},
+  {"_nlmixr2est_iniRxodePtrs", (DL_FUNC) &_nlmixr2est_iniRxodePtrs, 1},
+  {"_nlmixr2est_iniLotriPtr", (DL_FUNC) &_nlmixr2est_iniLotriPtr, 1},
   {"_nlmixr2est_uninformativeEta", (DL_FUNC) &_nlmixr2est_uninformativeEta, 1},
-  {"_nlmixr2est_popedSolveIdME2", (DL_FUNC) &_nlmixr2est_popedSolveIdME2, 7},
-  {"_nlmixr2est_popedSolveIdME", (DL_FUNC) &_nlmixr2est_popedSolveIdME, 7},
-  {"_nlmixr2est_popedFree", (DL_FUNC) &_nlmixr2est_popedFree, 0},
-  {"_nlmixr2est_popedSetup", (DL_FUNC) &_nlmixr2est_popedSetup, 2},
-  {"_nlmixr2est_popedSolveIdN", (DL_FUNC) &_nlmixr2est_popedSolveIdN, 4},
-  {"_nlmixr2est_popedSolveIdN2", (DL_FUNC) &_nlmixr2est_popedSolveIdN2, 4},
   {"_nlmixr2est_nlmGetParHist", (DL_FUNC) &_nlmixr2est_nlmGetParHist, 1},
   {"_nlmixr2est_nlmPrintHeader", (DL_FUNC) &_nlmixr2est_nlmPrintHeader, 0},
   {"_nlmixr2est_nlmSetScaleC", (DL_FUNC) &_nlmixr2est_nlmSetScaleC, 1},
@@ -205,7 +198,6 @@ void R_init_nlmixr2est(DllInfo *dll)
   R_registerRoutines(dll, CEntries, CallEntries, NULL, NULL);
   R_useDynamicSymbols(dll, TRUE);
   R_forceSymbols(dll,FALSE);
-  rxRmvnSEXPnlmixrEst = (_rxode2random_rxRmvnSEXP_t)R_GetCCallable("rxode2random","_rxode2random_rxRmvnSEXP");
 }
 
 void rxOptionsFreeFocei(void);
