@@ -28,7 +28,7 @@ nmTest({
 
     fit <- .nlmixr(one.cmt, theo_sd, est="saem")
 
-    skip_if_not(rxode2parse::.linCmtSens())
+    skip_if_not(rxode2::.linCmtSensB())
 
     expect_false(all(c("NPDE","EPRED","NPD","NPDE") %in% names(fit)))
     expect_warning(fit$etaSE)
